@@ -2,7 +2,7 @@ use strict;
 use warnings FATAL => 'all';
 
 package WWW::Mechanize::Cached;
-$WWW::Mechanize::Cached::VERSION = '1.48';
+$WWW::Mechanize::Cached::VERSION = '1.49';
 use 5.006;
 
 use Class::Load 'try_load_class';
@@ -44,10 +44,12 @@ sub _isa_warn_cache {
 sub _build_cache {
     my $self = shift;
 
-    return Cache::FileCache->new({
-        default_expires_in => '1d',
-        namespace          => 'www-mechanize-cached',
-    }) if try_load_class 'Cache::FileCache';
+    return Cache::FileCache->new(
+        {
+            default_expires_in => '1d',
+            namespace          => 'www-mechanize-cached',
+        }
+    ) if try_load_class 'Cache::FileCache';
     return CHI->new(
         driver     => 'File',
         expires_in => '1d',
@@ -239,7 +241,7 @@ WWW::Mechanize::Cached - Cache response to be polite
 
 =head1 VERSION
 
-version 1.48
+version 1.49
 
 =head1 SYNOPSIS
 
